=========
Tutorials
=========

The following are some tutorials which explain how to use the toolbox and show
how to use it to solve some problems.

.. toctree::
    :maxdepth: 1

    intro
    wavelet
    optimization
    pyramid
